@@ -1,4 +1,4 @@
-from dynabuffers.ast.AbstractAST import AbstractAST, ByteBuffer
+from dynabuffers.api.ISerializable import ISerializable, ByteBuffer
 from dynabuffers.ast.ClassType import ClassType
 
 
@@ -8,7 +8,7 @@ class UnionTypeOptions():
         self.values = values
 
 
-class UnionType(AbstractAST):
+class UnionType(ISerializable):
 
     def __init__(self, options):
         self.options = options
@@ -27,7 +27,9 @@ class UnionType(AbstractAST):
         index = buffer.get()
         clazz = registry.resolve(self.options.values[index])
 
-        return clazz.deserialize(buffer, registry)
+        map = clazz.deserialize(buffer, registry)
+        map[":type"] = index
+        return map
 
     def resolve(self, value, registry) -> ClassType:
         classes = list(map(lambda x: registry.resolve(x), self.options.values))
